﻿using CMS;
using CMS.EventLog;
using CMS.Helpers;
using CMS.Scheduler;
using CMS.SiteProvider;
using CMS.Synchronization;
using System;
using System.Data;
using System.Text;

[assembly: RegisterCustomClass("Custom.ObjectStagingTask", typeof(Custom.ObjectStagingTask))]
namespace Custom
{
    public class ObjectStagingTask : ITask
    {
        /// <summary>
        /// Executes the task.
        /// </summary>
        /// <param name="ti">Info object representing the scheduled task</param>
        public string Execute(TaskInfo ti)
        {
            int intSyncedTasks = 0;
            int intFailedTasks = 0;
            try
            {
                //Get all of the staging tasks
                foreach(StagingTaskInfo sti in StagingTaskInfoProvider.SelectTaskList(SiteContext.CurrentSiteID, 0, null, "TaskID", -1, "TaskID, TaskTitle"))
                {
                    try
                    {
                        StagingHelper.RunSynchronization(sti.TaskID, SiteContext.CurrentSiteID);
                        intSyncedTasks += 1;
                    }
                    catch (Exception)
                    {
                        intFailedTasks += 1;
                    }
                }

                string strResults = "Synced tasks: " + intSyncedTasks + " - Failed tasks: " + intFailedTasks;

                // Logs the execution of the task in the event log.
                EventLogProvider.LogInformation("ObjectStagingTask", "Execute", strResults);
                return strResults;
            }
            catch (Exception ex)
            {
                EventLogProvider.LogException("ObjectStagingTask", "Execute", ex);
                return "There was an error executing the task: " + ex.Message;
            }
        }
    }
}
